import argparse
from dnd_transcribe.inference import DEFAULT_MODEL


def build_argument_parser() -> argparse.ArgumentParser:
    parser = argparse.ArgumentParser(
        description="Utility to transcribe DND audio recordings."
    )
    parser.add_argument(
        "-v", "--verbose", action="store_true", help="Enable verbose logging"
    )
    parser.add_argument(
        "-q", "--quiet", action="store_true", help="Only display errors"
    )
    parser.add_argument(
        "--no-gpu",
        dest="use_gpu",
        action="store_false",
        help="Disable using the GPU with CUDA",
    )
    parser.add_argument(
        "-m",
        "--model",
        type=str,
        help="ASR model",
        default=DEFAULT_MODEL,
    )
    parser.add_argument(
        "-f",
        "--audio-file",
        type=argparse.FileType(mode="rb"),
        help="Audio file to process",
    )
    return parser
